@@ -5,18 +5,18 @@
 #'
 #' @seealso \code{\link{reliab_test}}
 #'
-#' @param df \code{data.frame} or matrix with more than 2 columns.
-#' @return The Cronbach's alpha value for \code{df}.
+#' @param data \code{data.frame} or matrix with more than 2 columns.
+#' @return The Cronbach's alpha value for \code{data}.
 #'
 #' @note See 'Examples' from \code{\link[sjPlot]{sjp.pca}} and \code{\link[sjPlot]{sjt.pca}}.
 #'
 #' @importFrom stats na.omit var
 #' @export
-cronb <- function(df) {
-  df <- stats::na.omit(df)
-  if (is.null(ncol(df)) || ncol(df) < 2) {
-    warning("Too less columns in this factor to calculate alpha value!", call. = F)
+cronb <- function(data) {
+  .data <- stats::na.omit(data)
+  if (is.null(ncol(.data)) || ncol(.data) < 2) {
+    warning("Too less columns `data`.", call. = F)
     return(NULL)
   }
-  return(dim(df)[2] / (dim(df)[2] - 1) * (1 - sum(apply(df, 2, var)) / stats::var(rowSums(df))))
+  return(dim(.data)[2] / (dim(.data)[2] - 1) * (1 - sum(apply(.data, 2, var)) / stats::var(rowSums(.data))))
 }
