@@ -411,15 +411,3 @@ set_values_vector <- function(x, labels, var.name, force.labels, force.values) {
   x <- set_labels(x, value, force.labels, force.values)
   x
 }
-
-
-#' @name set_val_labels
-#' @rdname set_labels
-#' @export
-set_val_labels <- function(x,
-                           labels,
-                           force.labels = FALSE,
-                           force.values = TRUE) {
-  .Deprecated("set_labels")
-  return(set_labels(x, labels, force.labels, force.values))
-}
