@@ -4,7 +4,7 @@
 #' @description This function splits categorical or numeric vectors with
 #'                more than two categories into 0/1-coded dummy variables.
 #'
-#' @param x a \code{\link{factor}}.
+#' @param x a \code{\link{vector}} (variable).
 #' @param var.name indicates how the new dummy variables are named. Use
 #'          \code{"name"} to use the variable name or any other string that will
 #'          be used as is. See 'Examples'.
@@ -38,7 +38,7 @@ to_dummy <- function(x, var.name = "name", suffix = "numeric", data = NULL) {
   if (suffix == "label") suffix <- "l"
   # correct abbr?
   if (suffix != "n" && suffix != "l") {
-    warning("argument `suffix` must be either \"numeric\" (or \"n\") or \"label\" (or \"l\"). Defaulting to \"numeric\" now.", call. = F)
+    warning("Argument `suffix` must be either `numeric` (or `n`) or `label` (or `l`). Defaulting to `numeric` now.", call. = F)
     suffix <- "n"
   }
   # save variable name
@@ -58,7 +58,7 @@ to_dummy <- function(x, var.name = "name", suffix = "numeric", data = NULL) {
     )
   # get resp. set variable label for new dummy variables
   # get variable label
-  label <- get_label(x, varname)
+  label <- get_label(x, def.value = varname)
   if (var.name != "name") varname <- var.name
   # get unique values
   values <- sort(unique(x))
